marginal_ci computes the marginal confidence interval for each parameters
using the variance-covariance matrix output by `varest.glinv`.
marginal_ci(varest_result, lvl = 0.95)A matrix \(p\)-by-2 matrix where \(p\) is the number of parameters. The first column is the lower limits and second column is the upper limits.
The output from `varest.glinv`.
Confidence level. Default to 95 percent.