nparams_ou: Get the number of parameters of the unrestricted OU model
Description
nparams_ou returns the number of parameters of the unrestricted OU model. For the restricted
models, including Brownian motion, see parameter_restriction for details.
Usage
nparams_ou(k)
Value
A numerical scalar, which is the number of parameters of the the unrestricted OU model.
Arguments
k
An Integer. The total number of dimensions of the multivariate traits.