| rglinv | R Documentation |
Simulate random trait values from the Gaussian branching process specified by mod.
rglinv(mod, par, Nsamp, simplify)
## S3 method for class 'glinv'
rglinv(mod, par, Nsamp = 1, simplify = TRUE)
## S3 method for class 'glinv_gauss'
rglinv(mod, par, Nsamp = 1, simplify = TRUE)
mod |
Either a |
par |
Parameters underlying the simulation, in the same format as |
Nsamp |
Number of sample point to simulate. |
simplify |
If TRUE, |
A list containing Nsamp elements, each of which represents a sample point from the model mod. The
format of each elements depends on the simplify argument.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.