Simulate random trait values from the Gaussian branching process specified by mod.
rglinv(mod, par, Nsamp, simplify)# S3 method for glinv
rglinv(mod, par, Nsamp = 1, simplify = TRUE)
# S3 method for glinv_gauss
rglinv(mod, par, Nsamp = 1, simplify = TRUE)
A list containing Nsamp elements, each of which represents a sample point from the model mod. The
format of each elements depends on the simplify argument.
Either a glinv_gauss or glinv object.
Parameters underlying the simulation, in the same format as lik.glinv_gauss or lik.glinv.
Number of sample point to simulate.
If TRUE, rglinv.glinv returns an Nsamp-element list with each element being a tip-trait matrix;
otherwise, rglinv.glinv returns an Nsamp-element list with each element being an \(n\)-element list
of \(k\)-element trait vectors, where \(n\) is the number of tips and \(k\) is the dimension of
each trait vector.